@@ -26,10 +26,6 @@ class Layer():
         srs = ""
         long_fields = {}
 
-        # Remove trailing and leading whitespace from field names in csv file
-        for i, field in enumerate(csv_text.fieldnames):
-            csv_text.fieldnames[i] = field.strip()
-
         for i, row in enumerate(csv_text):
             rowCorrected = []
             for f in self.fields[1:][:-1]:
@@ -39,17 +35,17 @@ class Layer():
                     data = row[f.field_name]
                 except:
                     if f.field_optional == False:
-                        msg = "Error! " + f.field_name + " is a required field but was not found in the imported file."
+                        msg = "Error! " + f.field_name + " is a required field but was not found in the imported file (or there is extraneous whitespace in the field name)."
                         valid, messages = addMessage(-1, False, msg, messages)
                         messages = format_messages(messages)
                         return valid, messages, [], {}, ""
                     else:
-                        msg = "Warning! " + f.field_name + " was not found in the imported file but this is not a required field so ignoring."
+                        msg = "Warning! " + f.field_name + " was not found in the imported file (or there is extraneous whitespace in the field name) but this is not a required field so ignoring."
                         valid, messages = addMessage(-1, valid, msg, messages)
                         data = ""
 
                 # Check encoding of data
-                encoding_error = check_encoding(data)
+                encoding_error = f.check_encoding(data)
                 valid, messages = addMessage(i, valid, encoding_error, messages)
 
                 if not encoding_error:
@@ -95,18 +91,6 @@ def get_primary_uri_field(fields):
 
     return None
 
-def check_encoding(data):
-    """Check that conversion to utf-8 and Win-1252 encoding (used by the server) is possible"""
-    msg = None
-
-    try:
-        data = data.encode("utf-8")
-        data = data.encode("windows-1252")
-    except:
-        msg = "Encoding Error! Found an unrecognized character in " + data + "."
-
-    return msg
-
 def addMessage(row_num, valid, new_msg, messages):
     """ Add error message to the list of errors and set the validity"""
 
